@@ -18,6 +18,12 @@ from exposurescrawler.utils.query_parsing import search_model_in_query
 
 
 def _should_ignore_workbook(workbook, projects_to_ignore: Collection[str]) -> bool:
+    # Personal spaces are usually used as a sandbox for experimental work
+    # and we ignore them in this project. In the Tabeau API, they are represented
+    # by workbooks under projects without a name.
+    if not workbook.project_name:
+        return True
+    
     return workbook.project_name in projects_to_ignore
 
 
